==> yndenz-lazy-loader-3.2.3-1b7b09.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [3.2.3] - 2019-04-15
### Fixed
- jQuery observer images at top of body (banner/gallery) not loading without scrolling
- jQuery observer reset list after loop instead of inside loop

## [3.2.2] - 2019-04-15
### Fixed
- getBoundingClientRect of undefined

## [3.2.1] - 2019-04-15
### Fixed
- Browser compatibility checking IntersectionObserver exists

## [3.2.0] - 2019-04-11
### Added
- Possibility to ignore IntersectionObserver
- Possibility to specify intersection distance

### Fixed
- IntersectionObserver checking intersection
- jQuery check image in viewport when scrolling up

## [3.1.2] - 2019-04-10
### Changed
- Remove console log

## [3.1.1] - 2019-04-10
### Added
- Possibility to load original just by calling a function

## [3.1.0] - 2019-04-09
### Added
- Possibility to define custom lazy loading policy

### Changed
- Check if file exists before trying to generate lazy image
- Do not exclude PageSpeed Insights from lazy loading functionality

### Fixed
- Instantly loading original when using IntersectionObserver due to wrong root

## [3.0.5] - 2019-03-12
### Changed
- Use NPM CI job to install dependencies from lock file

## [3.0.4] - 2019-03-12
### Changed
- Use npm install (production only) instead of update

## [3.0.3] - 2018-10-11
### Fixed
- NodeList is not an Array (so forEach doesn't work)

## [3.0.2] - 2018-10-10
### Fixed
- Do not use lazy image in WP Admin

## [3.0.1] - 2018-10-10
### Changed
- Google should load all images directly (no scroll event detected)

## [3.0.0] - 2018-10-03
### Added
- Function to create lazy (blurred) images
- Filter to apply lazy loading to all image attachments

### Changed
- Code style set to WordPress standards
- Remove dependency to jquery-lazyload

## [2.1.2] - 2018-09-17
### Fixed
- Always enqueue script (script-only module)

## [2.1.1] - 2018-09-17
### Changed
- Compatible with multiple version of base-module

## [2.1.0] - 2018-08-16
### Changed
- Upgrade to gulp v4 and new babel preset-env

## [2.0.1] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.3...HEAD
[3.2.3]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.2...3.2.3
[3.2.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.1...3.2.2
[3.2.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.0...3.2.1
[3.2.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.1.2...3.2.0
[3.1.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.1.1...3.1.2
[3.1.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.1.0...3.1.1
[3.1.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.5...3.1.0
[3.0.5]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.4...3.0.5
[3.0.4]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.3...3.0.4
[3.0.3]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.2...3.0.3
[3.0.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.1...3.0.2
[3.0.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.0...3.0.1
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.1.2...3.0.0
[2.1.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.1.1...2.1.2
[2.1.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.1.0...2.1.1
[2.1.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.0.1...2.1.0
[2.0.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.0.0...2.0.1

==> yndenz-lazy-loader-3.4.0-722526.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [3.4.0] - 2019-05-10
### Changed
- Introduced `data-clo` instead of changing the old behaviour 

## [3.3.0] - 2019-05-10
### Changed
- Changed the way providing a custom data policy works. 
  The loadOriginal method is the only method that can be overridden now. 

## [3.2.6] - 2019-05-01
### Fixed
- Added check if image exists in CheckIfInViewport function

## [3.2.5] - 2019-04-15
### Fixed
- Cannot read property distance of undefined

## [3.2.4] - 2019-04-15
### Added
- Possibility to test if image original should be loaded without actually loading original

## [3.2.3] - 2019-04-15
### Fixed
- jQuery observer images at top of body (banner/gallery) not loading without scrolling
- jQuery observer reset list after loop instead of inside loop

## [3.2.2] - 2019-04-15
### Fixed
- getBoundingClientRect of undefined

## [3.2.1] - 2019-04-15
### Fixed
- Browser compatibility checking IntersectionObserver exists

## [3.2.0] - 2019-04-11
### Added
- Possibility to ignore IntersectionObserver
- Possibility to specify intersection distance

### Fixed
- IntersectionObserver checking intersection
- jQuery check image in viewport when scrolling up

## [3.1.2] - 2019-04-10
### Changed
- Remove console log

## [3.1.1] - 2019-04-10
### Added
- Possibility to load original just by calling a function

## [3.1.0] - 2019-04-09
### Added
- Possibility to define custom lazy loading policy

### Changed
- Check if file exists before trying to generate lazy image
- Do not exclude PageSpeed Insights from lazy loading functionality

### Fixed
- Instantly loading original when using IntersectionObserver due to wrong root

## [3.0.5] - 2019-03-12
### Changed
- Use NPM CI job to install dependencies from lock file

## [3.0.4] - 2019-03-12
### Changed
- Use npm install (production only) instead of update

## [3.0.3] - 2018-10-11
### Fixed
- NodeList is not an Array (so forEach doesn't work)

## [3.0.2] - 2018-10-10
### Fixed
- Do not use lazy image in WP Admin

## [3.0.1] - 2018-10-10
### Changed
- Google should load all images directly (no scroll event detected)

## [3.0.0] - 2018-10-03
### Added
- Function to create lazy (blurred) images
- Filter to apply lazy loading to all image attachments

### Changed
- Code style set to WordPress standards
- Remove dependency to jquery-lazyload

## [2.1.2] - 2018-09-17
### Fixed
- Always enqueue script (script-only module)

## [2.1.1] - 2018-09-17
### Changed
- Compatible with multiple version of base-module

## [2.1.0] - 2018-08-16
### Changed
- Upgrade to gulp v4 and new babel preset-env

## [2.0.1] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.6...HEAD
[3.2.6]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.5...3.2.6
[3.2.5]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.4...3.2.5
[3.2.4]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.3...3.2.4
[3.2.3]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.2...3.2.3
[3.2.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.1...3.2.2
[3.2.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.2.0...3.2.1
[3.2.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.1.2...3.2.0
[3.1.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.1.1...3.1.2
[3.1.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.1.0...3.1.1
[3.1.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.5...3.1.0
[3.0.5]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.4...3.0.5
[3.0.4]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.3...3.0.4
[3.0.3]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.2...3.0.3
[3.0.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.1...3.0.2
[3.0.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/3.0.0...3.0.1
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.1.2...3.0.0
[2.1.2]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.1.1...2.1.2
[2.1.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.1.0...2.1.1
[2.1.0]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.0.1...2.1.0
[2.0.1]: https://gitlab.yndenz.com/yndenz-modules/lazy-loader/compare/2.0.0...2.0.1
